@@ -322,7 +322,9 @@ var menudata={children:[
 {text:"c",url:"globals_func_c.html#index_c"},
 {text:"g",url:"globals_func_g.html#index_g"},
 {text:"h",url:"globals_func_h.html#index_h"},
+{text:"i",url:"globals_func_i.html#index_i"},
 {text:"m",url:"globals_func_m.html#index_m"},
+{text:"o",url:"globals_func_o.html#index_o"},
 {text:"p",url:"globals_func_p.html#index_p"},
 {text:"r",url:"globals_func_r.html#index_r"},
 {text:"s",url:"globals_func_s.html#index_s"},
